## TODO

### Blockly
1. 连接安卓设备(done)

	<https://blockly-demo.appspot.com/static/demos/blockfactory/index.html#gq8gdg>

2. 监控

	<https://blockly-demo.appspot.com/static/demos/blockfactory/index.html#h3jyc4>

3. 坐标点击(done)

	<https://blockly-demo.appspot.com/static/demos/blockfactory/index.html#2zccrz>

### 测试用例草案
目录结构

```
testcase_examples/
├── blockly.py
├── blockly.xml
└── images
    └── blockly
        └── button@rsl(1080x1920)offset(12_30).png
```

